Roles
=====

.. currentmodule:: pglift.roles

Module :mod:`pglift.roles` exposes the following API to manipulate
PostgreSQL roles:

.. autofunction:: create
.. autofunction:: alter
.. autofunction:: apply
.. autofunction:: exists
.. autofunction:: get
.. autofunction:: drop
